Learn R Programming

tergo (version 0.1.9)

style_pkg_addin: Style the current package (RStudio addin)

Description

Automatically styles all R code in the current project/package using style_pkg. If not called within a project, it defaults to the current working directory.

Usage

style_pkg_addin()

Arguments

Value

invisibly returns NULL.