Learn R Programming

tergo (version 0.1.9)

tergo-package: A library to make your source code pretty.

Description

Provides a set of functions that allow users for styling their R code according to the 'tidyverse' style guide. The package uses a native Rust implementation to ensure the highest performance. Learn more about 'tergo' at https://rtergo.pagacz.io.

Arguments

Author

Maintainer: Konrad Pagacz konrad.pagacz@gmail.com

Other contributors:

  • Maciej Nasinski nasinski.maciej@gmail.com [contributor]

  • The authors of the dependency Rust crates (see inst/AUTHORS file for details) [contributor]

See Also