Provides a set of functions that allow users for styling their R code according to the 'tidyverse' style guide. The package uses a native Rust implementation to ensure the highest performance. Learn more about 'tergo' at https://rtergo.pagacz.io.
Maintainer: Konrad Pagacz konrad.pagacz@gmail.com
Other contributors:
Maciej Nasinski nasinski.maciej@gmail.com [contributor]
The authors of the dependency Rust crates (see inst/AUTHORS file for details) [contributor]
Useful links: